@@ -3,7 +3,6 @@ Tests for the `edx_name_affirmation` Python API.
 """
 
 import ddt
-from edx_toggles.toggles.testutils import override_waffle_flag
 
 from django.contrib.auth import get_user_model
 from django.core.cache import cache
@@ -14,7 +13,6 @@ from edx_name_affirmation.api import (
     create_verified_name_config,
     get_verified_name,
     get_verified_name_history,
-    is_verified_name_enabled,
     should_use_verified_name_for_certs,
     update_verification_attempt_id,
     update_verified_name_status
@@ -27,7 +25,6 @@ from edx_name_affirmation.exceptions import (
 )
 from edx_name_affirmation.models import VerifiedName, VerifiedNameConfig
 from edx_name_affirmation.statuses import VerifiedNameStatus
-from edx_name_affirmation.toggles import VERIFIED_NAME_FLAG
 
 User = get_user_model()
 
@@ -160,6 +157,38 @@ class TestVerifiedNameAPI(TestCase):
 
         self.assertIsNone(verified_name_obj)
 
+    @ddt.data(
+        ([VerifiedNameStatus.PENDING], VerifiedNameStatus.DENIED),
+        ([VerifiedNameStatus.DENIED, VerifiedNameStatus.PENDING], VerifiedNameStatus.APPROVED),
+        (['invalid status'], VerifiedNameStatus.PENDING)
+    )
+    @ddt.unpack
+    def test_get_verified_name_exclude(self, statuses_to_exclude, expected_status):
+        """
+        Exclude verified names by status when getting the most recent verified name.
+        """
+        self._create_verified_name(status=VerifiedNameStatus.APPROVED)
+        self._create_verified_name(status=VerifiedNameStatus.DENIED)
+        self._create_verified_name(status=VerifiedNameStatus.PENDING)
+
+        verified_name_obj = get_verified_name(self.user, False, statuses_to_exclude)
+
+        self.assertEqual(verified_name_obj.status, expected_status)
+
+    @ddt.data(False, True)
+    def test_get_verified_name_ignore_exlude_parameter(self, is_verified):
+        """
+        If `is_verified` is True, ignore the `statuses_to_exclude` parameter.
+        """
+        self._create_verified_name(status=VerifiedNameStatus.APPROVED)
+
+        verified_name_obj = get_verified_name(self.user, is_verified, [VerifiedNameStatus.APPROVED])
+
+        if is_verified:
+            self.assertEqual(verified_name_obj.verified_name, self.VERIFIED_NAME)
+        else:
+            self.assertIsNone(verified_name_obj)
+
     def test_get_verified_name_history(self):
         """
         Test that get_verified_name_history returns all of the user's VerifiedNames
@@ -314,10 +343,3 @@ class TestVerifiedNameAPI(TestCase):
         create_verified_name_config(self.user, use_verified_name_for_certs=True)
         create_verified_name_config(self.user)
         self.assertTrue(should_use_verified_name_for_certs(self.user))
-
-    def test_is_verified_name_enabled_false(self):
-        self.assertFalse(is_verified_name_enabled())
-
-    @override_waffle_flag(VERIFIED_NAME_FLAG, True)
-    def test_is_verified_name_enabled_true(self):
-        self.assertTrue(is_verified_name_enabled())
