@@ -3,7 +3,7 @@ Name Affirmation HTTP-based API endpoints
 """
 
 from edx_rest_framework_extensions.auth.jwt.authentication import JwtAuthentication
-from rest_framework import status
+from rest_framework import status as http_status
 from rest_framework.authentication import SessionAuthentication
 from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
@@ -14,12 +14,22 @@ from django.contrib.auth import get_user_model
 from edx_name_affirmation.api import (
     create_verified_name,
     create_verified_name_config,
+    delete_verified_name,
     get_verified_name,
     get_verified_name_history,
-    should_use_verified_name_for_certs
+    should_use_verified_name_for_certs,
+    update_verified_name_status
+)
+from edx_name_affirmation.exceptions import (
+    VerifiedNameAttemptIdNotGiven,
+    VerifiedNameDoesNotExist,
+    VerifiedNameMultipleAttemptIds
+)
+from edx_name_affirmation.serializers import (
+    UpdateVerifiedNameSerializer,
+    VerifiedNameConfigSerializer,
+    VerifiedNameSerializer
 )
-from edx_name_affirmation.exceptions import VerifiedNameMultipleAttemptIds
-from edx_name_affirmation.serializers import VerifiedNameConfigSerializer, VerifiedNameSerializer
 from edx_name_affirmation.statuses import VerifiedNameStatus
 
 
@@ -39,6 +49,8 @@ class VerifiedNameView(AuthenticatedAPIView):
     Supports:
         HTTP POST: Creates a new VerifiedName.
         HTTP GET: Returns an existing VerifiedName (by username or requesting user)
+        HTTP PATCH: Update the status of a VerifiedName
+        HTTP DELETE: Delete a VerifiedName
 
     HTTP POST
     Creates a new VerifiedName.
@@ -64,6 +76,19 @@ class VerifiedNameView(AuthenticatedAPIView):
             "status": "approved",
             "use_verified_name_for_certs": False,
         }
+
+    HTTP PATCH
+        * Update the status of a VerifiedName
+            Example PATCH data: {
+                "username": "jdoe",
+                "verification_attempt_id" OR "proctored_exam_attempt_id": 123,
+                "status": "approved",
+            }
+
+    HTTP DELETE
+        * Delete a VerifiedName
+        /edx_name_affirmation/v1/verified_name/{id}
+
     """
     def get(self, request):
         """
@@ -72,7 +97,7 @@ class VerifiedNameView(AuthenticatedAPIView):
         username = request.GET.get('username')
         if username and not request.user.is_staff:
             return Response(
-                status=status.HTTP_403_FORBIDDEN,
+                status=http_status.HTTP_403_FORBIDDEN,
                 data={"detail": "Must be a Staff User to Perform this request."}
             )
 
@@ -82,7 +107,6 @@ class VerifiedNameView(AuthenticatedAPIView):
             return Response(
                 status=404,
                 data={'detail': 'There is no verified name related to this user.'}
-
             )
 
         serialized_data = VerifiedNameSerializer(verified_name).data
@@ -96,7 +120,7 @@ class VerifiedNameView(AuthenticatedAPIView):
         username = request.data.get('username')
         if username != request.user.username and not request.user.is_staff:
             return Response(
-                status=status.HTTP_403_FORBIDDEN,
+                status=http_status.HTTP_403_FORBIDDEN,
                 data={"detail": "Must be a Staff User to Perform this request."}
             )
 
@@ -112,16 +136,73 @@ class VerifiedNameView(AuthenticatedAPIView):
                     proctored_exam_attempt_id=request.data.get('proctored_exam_attempt_id', None),
                     status=request.data.get('status', VerifiedNameStatus.PENDING)
                 )
-                response_status = status.HTTP_200_OK
+                response_status = http_status.HTTP_200_OK
                 data = {}
             except VerifiedNameMultipleAttemptIds as exc:
-                response_status = status.HTTP_400_BAD_REQUEST
+                response_status = http_status.HTTP_400_BAD_REQUEST
                 data = {"detail": str(exc)}
         else:
-            response_status = status.HTTP_400_BAD_REQUEST
+            response_status = http_status.HTTP_400_BAD_REQUEST
             data = serializer.errors
         return Response(status=response_status, data=data)
 
+    def patch(self, request):
+        """
+        Update verified name status
+        """
+        if not request.user.is_staff:
+            return Response(
+                status=http_status.HTTP_403_FORBIDDEN,
+                data={'detail': 'Must be a staff user to update verified name status.'}
+            )
+
+        serializer = UpdateVerifiedNameSerializer(data=request.data)
+
+        if serializer.is_valid():
+            username = request.data.get('username')
+            user = get_user_model().objects.get(username=username)
+            try:
+                verified_name = update_verified_name_status(
+                    user,
+                    request.data.get('status'),
+                    request.data.get('verification_attempt_id', None),
+                    request.data.get('proctored_exam_attempt_id', None)
+                )
+                response_status = http_status.HTTP_200_OK
+                data = VerifiedNameSerializer(verified_name).data
+            except (VerifiedNameAttemptIdNotGiven, VerifiedNameMultipleAttemptIds) as exc:
+                response_status = http_status.HTTP_400_BAD_REQUEST
+                data = {'detail': str(exc)}
+            except VerifiedNameDoesNotExist as exc:
+                response_status = http_status.HTTP_404_NOT_FOUND
+                data = {'detail': str(exc)}
+        else:
+            response_status = http_status.HTTP_400_BAD_REQUEST
+            data = serializer.errors
+
+        return Response(status=response_status, data=data)
+
+    def delete(self, request, verified_name_id):
+        """
+        Delete verified name
+        /edx_name_affirmation/v1/verified_name/{verified_name_id}
+        """
+        if not request.user.is_staff:
+            return Response(
+                status=http_status.HTTP_403_FORBIDDEN,
+                data={'detail': 'Must be a staff user to delete a verified name.'}
+            )
+
+        try:
+            delete_verified_name(verified_name_id)
+            response_status = http_status.HTTP_204_NO_CONTENT
+            data = {}
+        except VerifiedNameDoesNotExist as exc:
+            response_status = http_status.HTTP_404_NOT_FOUND
+            data = {'detail': str(exc)}
+
+        return Response(status=response_status, data=data)
+
 
 class VerifiedNameHistoryView(AuthenticatedAPIView):
     """
@@ -138,7 +219,7 @@ class VerifiedNameHistoryView(AuthenticatedAPIView):
         username = request.GET.get('username')
         if username and not request.user.is_staff:
             return Response(
-                status=status.HTTP_403_FORBIDDEN,
+                status=http_status.HTTP_403_FORBIDDEN,
                 data={"detail": "Must be a Staff User to Perform this request."}
             )
 
@@ -176,7 +257,7 @@ class VerifiedNameConfigView(AuthenticatedAPIView):
         username = request.data.get('username')
         if username != request.user.username and not request.user.is_staff:
             msg = 'Must be a staff user to override the requested user’s VerifiedNameConfig value'
-            return Response(status=status.HTTP_403_FORBIDDEN, data={'detail': msg})
+            return Response(status=http_status.HTTP_403_FORBIDDEN, data={'detail': msg})
 
         serializer = VerifiedNameConfigSerializer(data=request.data)
 
@@ -186,11 +267,11 @@ class VerifiedNameConfigView(AuthenticatedAPIView):
                 user,
                 use_verified_name_for_certs=request.data.get('use_verified_name_for_certs'),
             )
-            response_status = status.HTTP_201_CREATED
+            response_status = http_status.HTTP_201_CREATED
             data = {}
 
         else:
-            response_status = status.HTTP_400_BAD_REQUEST
+            response_status = http_status.HTTP_400_BAD_REQUEST
             data = serializer.errors
 
         return Response(status=response_status, data=data)
